@@ -10,11 +10,13 @@
 #' @return a dataframe.
 #'
 #' @examples
-#' car_fleet(by = "month")
+#' \dontrun{car_fleet(by = "month")}
 #'
 #' @export
 car_fleet <- function(by) {
 
+  options(scipen = 999, timeout = 1500)
+
   if(by == 'month') {
     link <- 'https://www.ispdados.rj.gov.br/Arquivos/FrotaVeiculoEstadoMES.csv'
   }
@@ -23,9 +25,25 @@ car_fleet <- function(by) {
     link <- 'https://www.ispdados.rj.gov.br/Arquivos/FrotaVeiculoEstadoANO.csv'
   }
 
-  df <- readr::read_csv2(link, locale = readr::locale(encoding = "latin1"), show_col_types = FALSE) |>
-    janitor::clean_names()
+  suppressWarnings({
+
+    tryCatch({
+      df <-  readr::read_csv2(link, locale = readr::locale(encoding = "latin1"),
+                              show_col_types = FALSE) |>
+        janitor::clean_names()
+      message("Query completed.")
+
+    },
+    # show error message
+
+    error = function(e) {
+      message("Error downloading file. Try again later.") }
+    )
+
+  })
+
+  old <- options(timeout = 60)
+  on.exit(options(old))
 
-  message('Query completed.')
   return(df)
 }
