@@ -12,11 +12,13 @@
 #' @return a dataframe
 #'
 #' @examples
-#' spatial_info(data = "code_equivalence")
+#' \dontrun{spatial_info(data = "code_equivalence")}
 #'
 #' @export
 spatial_info <- function(data) {
 
+  options(scipen = 999, timeout = 1500)
+
   if(data == "code_equivalence") {
     link <- "https://www.ispdados.rj.gov.br/Arquivos/Relacao_RISPxAISPxCISP.csv"
   }
@@ -25,10 +27,25 @@ spatial_info <- function(data) {
     link <- "https://www.ispdados.rj.gov.br/Arquivos/AreasemKm.csv"
   }
 
-  df <-  readr::read_csv2(link, locale = readr::locale(encoding = "latin1"), show_col_types = FALSE) |>
-    janitor::clean_names()
+  suppressWarnings({
 
-  message('Query completed.')
+    tryCatch({
+      df <-  readr::read_csv2(link, locale = readr::locale(encoding = "latin1"), show_col_types = FALSE) |>
+        janitor::clean_names()
+
+      message('Query completed.')
+
+    },
+    # show error message
+
+    error = function(e) {
+      message("Error downloading file. Try again later.") }
+    )
+
+  })
+
+  old <- options(timeout = 60)
+  on.exit(options(old))
   return(df)
 
 }
