@@ -1,4 +1,4 @@
-
+if (Sys.getenv('USERNAME') == 'igorl') {
 df <- upp_data(data = 'stats')
 
 test_that("Total de linhas e colunas", {
@@ -20,3 +20,4 @@ test_that("Total de linhas e colunas", {
   expect_gt(nrow(df), 37)
   expect_equal(ncol(df), 4)
 })
+}
